/**
*	Author:	Elizabeth Labelle
*	Project:	Boids Simulation
*	Date:		December 2010
*
*	Description: The BoidManagerGizmo is an Editor script which can be attached to a
*					BoidManager. In the UnityEditor, the Gizmo script will draw a green sphere at
*					the BoidManager's current position until the program starts. Afterwards, a red
*					sphere will indicate the current center of the flock.
*					This is useful for debugging and does not show up in the final build.
*/
using UnityEngine;
using System.Collections;

public class BoidManagerGizmo : MonoBehaviour 
{
	/**	Draw a green sphere at the BoidManager's current position until the program starts.
	*		When program begins show a red sphere to indicate the current center of the flock.
	**/
	void OnDrawGizmos()
	{
		BoidManager[] worldData = GetComponents<BoidManager>();
		
		foreach(BoidManager bmanager in worldData)
		{
			Vector3 pos;
			float bmRadius;
			
			if(Application.isPlaying)
			{
				//When the application is running, show the center of the flock
				pos = bmanager.boidCenter;
				//and do not show the spawn radius, which is no longer needed
				bmRadius = 1.5f;
				Gizmos.color = Color.red;
			}
			else
			{
				//if the application is not running, show the spawn location
				pos = transform.position;
				//and the size of the spawn point
				bmRadius = bmanager.spawnRadius;
				Gizmos.color = Color.green;
			}
			
			Gizmos.DrawWireSphere(pos, bmRadius);
		}
	}
}
