/**
*	Author:	Elizabeth Labelle
*	Project:	Boids Simulation
*	Date:		December 2010
*
*	Description: The WorldGizmo is an Editor script which can be attached to a
*					World GameObject. In the UnityEditor, the Gizmo script will draw a world icon
*					the Worlds current position. It will also draw a rectangle indicating the current world
*					boundary.
*					This is useful for debugging and does not show up in the final build.
*/
using UnityEngine;
using System.Collections;

public class WorldGizmo : MonoBehaviour {

	void OnDrawGizmos()
	{
		Gizmos.DrawIcon(transform.position, "world.png");
		
		World worldData = GetComponent<World>();
		
		if(worldData != null)
		{//draw a cube showing the area Boids are allowed in
			//draw square on ground
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMin, worldData.zMin), 
									new Vector3(worldData.xMax, worldData.yMin, worldData.zMin));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMin, worldData.zMin),
									new Vector3(worldData.xMax, worldData.yMin, worldData.zMax));
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMin, worldData.zMin),
									new Vector3(worldData.xMin, worldData.yMin, worldData.zMax));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMin, worldData.zMax), 
									new Vector3(worldData.xMin, worldData.yMin, worldData.zMax));
			
			//draw square in air
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMax, worldData.zMin),
									new Vector3(worldData.xMax, worldData.yMax, worldData.zMin));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMax, worldData.zMin), 
									new Vector3(worldData.xMax, worldData.yMax, worldData.zMax));
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMax, worldData.zMin),
									new Vector3(worldData.xMin, worldData.yMax, worldData.zMax));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMax, worldData.zMax), 
									new Vector3(worldData.xMin, worldData.yMax, worldData.zMax));
			
			//draw vertical lines
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMin, worldData.zMin), 
									new Vector3(worldData.xMin, worldData.yMax, worldData.zMin));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMin, worldData.zMin), 
									new Vector3(worldData.xMax, worldData.yMax, worldData.zMin));
			Gizmos.DrawLine(new Vector3(worldData.xMin, worldData.yMin, worldData.zMax), 
									new Vector3(worldData.xMin, worldData.yMax, worldData.zMax));
			Gizmos.DrawLine(new Vector3(worldData.xMax, worldData.yMin, worldData.zMax), 
									new Vector3(worldData.xMax, worldData.yMax, worldData.zMax));
		}
	}
}
